var searchData=
[
  ['baddimension_0',['BadDimension',['../classgko_1_1BadDimension.html#a774454482004beac61bd983f74f446c3',1,'gko::BadDimension']]],
  ['batch_5fdim_1',['batch_dim',['../structgko_1_1batch__dim.html#a9ad0e2ce59184e0969c4cfbbccd16fbc',1,'gko::batch_dim::batch_dim()'],['../structgko_1_1batch__dim.html#a084efe247f49ff54a4156858991a2eb5',1,'gko::batch_dim::batch_dim(const size_type num_batch_items, const dim&lt; dimensionality, dimension_type &gt; &amp;common_size)']]],
  ['bind_5fto_5fcore_2',['bind_to_core',['../classgko_1_1machine__topology.html#a9a18cb07c0fcc866997c727abfac52d9',1,'gko::machine_topology']]],
  ['bind_5fto_5fcores_3',['bind_to_cores',['../classgko_1_1machine__topology.html#aa63dcb3e4080720109cf9e48bfc97f42',1,'gko::machine_topology']]],
  ['bind_5fto_5fpu_4',['bind_to_pu',['../classgko_1_1machine__topology.html#a9788d302561048fa91257f71ca9fa4be',1,'gko::machine_topology']]],
  ['bind_5fto_5fpus_5',['bind_to_pus',['../classgko_1_1machine__topology.html#a6c1579ec42001ec51ecb7102578bd932',1,'gko::machine_topology']]],
  ['block_5fat_6',['block_at',['../classgko_1_1BlockOperator.html#a8ae64878f419a1719010efa49c660279',1,'gko::BlockOperator']]],
  ['blockoperator_7',['BlockOperator',['../classgko_1_1BlockOperator.html#acb8ff1788a332231a3e9f8199dec0d03',1,'gko::BlockOperator::BlockOperator(const BlockOperator &amp;other)'],['../classgko_1_1BlockOperator.html#a4066b33a9d42462429c76eea3f9532c1',1,'gko::BlockOperator::BlockOperator(BlockOperator &amp;&amp;other) noexcept']]],
  ['blocksizeerror_8',['BlockSizeError',['../classgko_1_1BlockSizeError.html#a861999cfafdd726814ef4bcd06734bd7',1,'gko::BlockSizeError']]],
  ['broadcast_9',['broadcast',['../classgko_1_1experimental_1_1mpi_1_1communicator.html#a95ea693d1ddc249215968d378e80dcc7',1,'gko::experimental::mpi::communicator']]],
  ['build_10',['build',['../classgko_1_1experimental_1_1factorization_1_1Cholesky.html#a154cada7f11335b0148b946e3b6ad85f',1,'gko::experimental::factorization::Cholesky::build()'],['../classgko_1_1experimental_1_1factorization_1_1Lu.html#a61cd8064ed1566c54912183bfeae5e5e',1,'gko::experimental::factorization::Lu::build()'],['../classgko_1_1preconditioner_1_1GaussSeidel.html#a7dbce0fc2e2e9a1eaca030a9f368b739',1,'gko::preconditioner::GaussSeidel::build()'],['../classgko_1_1preconditioner_1_1Sor.html#a23c746f50487fe2824c3957995645099',1,'gko::preconditioner::Sor::build()'],['../classgko_1_1experimental_1_1reorder_1_1Amd.html#a03fa10a26c275d6aa5e87c97836f3169',1,'gko::experimental::reorder::Amd::build()'],['../classgko_1_1experimental_1_1reorder_1_1Mc64.html#acf4ff0eb6edb11ea44b9745ece9ded65',1,'gko::experimental::reorder::Mc64::build()'],['../classgko_1_1experimental_1_1reorder_1_1Rcm.html#a6be4bed40dd659bc915f4320c6f1ab81',1,'gko::experimental::reorder::Rcm::build()']]],
  ['build_5ffrom_5fcontiguous_11',['build_from_contiguous',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#acbc987df113d50d6cdf6d6b605a15860',1,'gko::experimental::distributed::Partition']]],
  ['build_5ffrom_5fglobal_5fsize_5funiform_12',['build_from_global_size_uniform',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#a54bfa82bec475057cba794814342505e',1,'gko::experimental::distributed::Partition']]],
  ['build_5ffrom_5fmapping_13',['build_from_mapping',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#ad17d1164a99bca5df2d2ec0eb5d79c2f',1,'gko::experimental::distributed::Partition']]],
  ['build_5fpartition_5ffrom_5flocal_5frange_14',['build_partition_from_local_range',['../namespacegko_1_1experimental_1_1distributed.html#ae0368295654a9d8455731832a88ffc8c',1,'gko::experimental::distributed']]],
  ['build_5fpartition_5ffrom_5flocal_5fsize_15',['build_partition_from_local_size',['../namespacegko_1_1experimental_1_1distributed.html#a6fff69d2898fefe193012da079a2fef0',1,'gko::experimental::distributed']]],
  ['build_5fsmoother_16',['build_smoother',['../namespacegko_1_1solver.html#ac565c4b95ad0c67492073d993a9170cc',1,'gko::solver::build_smoother(std::shared_ptr&lt; const LinOpFactory &gt; factory, size_type iteration=1, ValueType relaxation_factor=0.9)'],['../namespacegko_1_1solver.html#aadb962ce0b5566e83fcdb22dda6e3cf8',1,'gko::solver::build_smoother(std::shared_ptr&lt; const LinOp &gt; solver, size_type iteration=1, ValueType relaxation_factor=0.9)']]]
];
